collections/callbacks library

Typedefs

Func1Callback<TValue, TReturn> = TReturn Function(TValue)
A callback that receives a value of type TValue and returns a value of type TReturn.
Func2Callback<TValue1, TValue2, TReturn> = TReturn Function(TValue1, TValue2)
A callback that receives values of type TValue1 and TValue2 and returns a value of type TReturn.
FuncCallback<TReturn> = TReturn Function()
A callback that takes no arguments and returns a value of type TReturn.
ObjCallback = void Function(Object)
A callback that receives a non-null Object.
ObjCallbackNullable = void Function(Object?)
A callback that receives a nullable Object.
ValueCallback<TValue> = void Function(TValue)
A callback that receives a value of type TValue.
VoidCallback = void Function()
A callback that takes no arguments and returns nothing.