ValueCallback<TValue> typedef
ValueCallback<TValue> =
void Function(TValue)
A callback that receives a value of type TValue.
Implementation
typedef ValueCallback<TValue> = void Function(TValue);
A callback that receives a value of type TValue.
typedef ValueCallback<TValue> = void Function(TValue);