VoidCallback typedef
VoidCallback =
void Function()
A callback that takes no arguments and returns nothing.
Implementation
typedef VoidCallback = void Function();
A callback that takes no arguments and returns nothing.
typedef VoidCallback = void Function();