collections/generic_list library
Classes
-
GenericList<
TItem> - A list that associates an arbitrary generic type with each item. When the list is iterated, the list's GenericListHandler will be invoked with the item and its associated generic type.
-
GenericListHandler<
TItem> - Handler invoked for each item in a GenericList during iteration.