GenericListHandler<TItem> class abstract interface

Handler invoked for each item in a GenericList during iteration.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleGenericListItem<TAssociated>(GenericList<TItem> list, TItem item) → void
Handles a single item from the list along with its associated generic type TAssociated.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited