collections/generic_queue library

Classes

GenericQueue
A queue that preserves the generic type of each enqueued item.
GenericQueueHandler
Handler invoked when an item is dequeued from a GenericQueue.