Handler invoked when an item is dequeued from a GenericQueue.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleGenericQueueItem<
TItem extends Object> (GenericQueue queue, TItem value) → void -
Handles a single dequeued item along with its generic type
TItem. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited