Context class abstract interface

Logic block execution context provided to each state.

The context allows states to interact with their parent logic block by adding inputs, producing outputs, reading blackboard data, and reporting errors.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
isStarted bool
Whether the logic block is currently running and can accept inputs.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addError(Object e) → void
Adds an error to the logic block. Errors are immediately processed by the logic block's LogicBlock.handleError callback.
get<TData extends Object>() → TData
Gets a value of type TData from the logic block's blackboard.
input<TInput extends Object>(TInput input) → void
Adds an input value to the logic block's internal input queue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output<TOutput extends Object>(TOutput output) → void
Produces a logic block output value.
toString() String
A string representation of this object.
inherited
trackFuture(Future<void> future) → void
Tracks a Future so that LogicBlock.task will not complete until future has finished.

Operators

operator ==(Object other) bool
The equality operator.
inherited