isStarted property
bool
get
isStarted
Whether the logic block is currently running and can accept inputs.
Implementation
bool get isStarted;
Whether the logic block is currently running and can accept inputs.
bool get isStarted;