bind method
Creates a new LogicBlockBinding that listens to this logic block.
Always dispose the returned binding when you are finished with it.
Implementation
LogicBlockBinding<TState> bind() => _LogicBlockBinding<TState>(this);
Creates a new LogicBlockBinding that listens to this logic block.
Always dispose the returned binding when you are finished with it.
LogicBlockBinding<TState> bind() => _LogicBlockBinding<TState>(this);