getInitialState abstract method

Transition getInitialState()

Returns a Transition representing the initial state of the logic block.

Implementations must override this to specify which state the logic block starts in by calling to.

Implementation

Transition getInitialState();