handleError method

  1. @protected
void handleError(
  1. Object e
)

Called whenever an error is reported by a state. Override to handle errors produced during state logic execution.

Implementation

@protected
void handleError(Object e) {}