isStarted property
bool
get
isStarted
Whether the logic block is currently started and can receive inputs.
Implementation
bool get isStarted => _status == LogicBlockStatus.started;
Whether the logic block is currently started and can receive inputs.
bool get isStarted => _status == LogicBlockStatus.started;