async<T> method
Wraps a Future so that its result is delivered as an input to the logic block. Chain StatefulFuture.input and StatefulFuture.errorInput to define which inputs to fire.
The input will be delivered even if this state has been replaced by the time the future completes. If the logic block has been stopped or disposed, the input is silently discarded.
Implementation
@protected
StatefulFuture<T> async<T>(Future<T> future) =>
StatefulFuture._(_internalState.contextAdapter, future);