isAttached property
bool
get
isAttached
Whether this state is currently attached to a logic block context.
Implementation
bool get isAttached => _internalState.isAttached;
Whether this state is currently attached to a logic block context.
bool get isAttached => _internalState.isAttached;