LogicBlock<TState extends StateLogic<TState> > constructor
LogicBlock<TState extends StateLogic<TState> > ()
A logic block. Logic blocks are machines that receive input, maintain a single state, and produce outputs. They can be used as simple input-to-state reducers or built upon to create hierarchical state machines.
Implementation
LogicBlock() {
_inputs = GenericQueue(handler: this);
_context = _DefaultContext<TState>(this);
}