handleError method
Called whenever an error is reported by a state. Override to handle errors produced during state logic execution.
Implementation
@protected
void handleError(Object e) {}
Called whenever an error is reported by a state. Override to handle errors produced during state logic execution.
@protected
void handleError(Object e) {}