stop method
void
stop()
Stops the logic block, calling exit and detach callbacks on the current state before clearing the input queue.
Throws a StateError if the logic block has been disposed. Has no effect if not started or currently processing.
Implementation
void stop() {
_throwIfDisposed('stop');
if (!isStarted || isProcessing) {
return;
}
_changeState(null);
_inputs.clear();
_value = null;
_status = LogicBlockStatus.stopped;
onStop();
}