LogicBlockBase class abstract base

Base class for all logic blocks. Provides access to the blackboard and the current state as an Object.

Implementers

Constructors

LogicBlockBase()

Properties

blackboard Blackboard
The blackboard data store shared across states.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueAsObject Object?
The current state as an untyped Object, or null if the logic block has not been started.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited