on<TInput> method
Register an input handler for inputs of type TInput. Input instances
which have the same runtime type as TInput will be passed to handler.
Only one handler can be registered per input type — subsequent calls with
the same input type will overwrite the previous handler.
Implementation
@protected
void on<TInput>(Func1Callback<TInput, Transition> handler) =>
_internalState.on<TInput>(handler);