onAny method

  1. @protected
void onAny(
  1. Func1Callback<Object, Transition> handler
)

Register a fallback handler that is called for any input that does not have a specific on handler registered. Specific handlers always take priority over onAny.

Implementation

@protected
void onAny(Func1Callback<Object, Transition> handler) =>
    _internalState.onAny(handler);